@@ -6,14 +6,15 @@ Type annotations for rbin service client paginators.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
 
-    from mypy_boto3_rbin import RecycleBinClient
+    from mypy_boto3_rbin.client import RecycleBinClient
     from mypy_boto3_rbin.paginator import (
         ListRulesPaginator,
     )
 
-    client: RecycleBinClient = boto3.client("rbin")
+    session = Session()
+    client: RecycleBinClient = session.client("rbin")
 
     list_rules_paginator: ListRulesPaginator = client.get_paginator("list_rules")
     ```
@@ -41,7 +42,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListRulesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.48/reference/services/rbin.html#RecycleBin.Paginator.ListRules)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rbin.html#RecycleBin.Paginator.ListRules)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rbin/paginators.html#listrulespaginator)
     """
 
@@ -53,6 +54,6 @@ class ListRulesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRulesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.48/reference/services/rbin.html#RecycleBin.Paginator.ListRules.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rbin.html#RecycleBin.Paginator.ListRules.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rbin/paginators.html#listrulespaginator)
         """
