@@ -14,6 +14,8 @@ Usage::
 import sys
 from typing import Dict, List, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import ResourceTypeType, RuleStatusType
 
 if sys.version_info >= (3, 9):
@@ -48,29 +50,16 @@ __all__ = (
     "UpdateRuleResponseTypeDef",
 )
 
-_RequiredCreateRuleRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateRuleRequestRequestTypeDef",
+CreateRuleRequestRequestTypeDef = TypedDict(
+    "CreateRuleRequestRequestTypeDef",
     {
         "RetentionPeriod": "RetentionPeriodTypeDef",
         "ResourceType": ResourceTypeType,
+        "Description": NotRequired[str],
+        "Tags": NotRequired[Sequence["TagTypeDef"]],
+        "ResourceTags": NotRequired[Sequence["ResourceTagTypeDef"]],
     },
 )
-_OptionalCreateRuleRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateRuleRequestRequestTypeDef",
-    {
-        "Description": str,
-        "Tags": Sequence["TagTypeDef"],
-        "ResourceTags": Sequence["ResourceTagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateRuleRequestRequestTypeDef(
-    _RequiredCreateRuleRequestRequestTypeDef, _OptionalCreateRuleRequestRequestTypeDef
-):
-    pass
-
 
 CreateRuleResponseTypeDef = TypedDict(
     "CreateRuleResponseTypeDef",
@@ -113,28 +102,15 @@ GetRuleResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListRulesRequestRequestTypeDef = TypedDict(
-    "_RequiredListRulesRequestRequestTypeDef",
+ListRulesRequestRequestTypeDef = TypedDict(
+    "ListRulesRequestRequestTypeDef",
     {
         "ResourceType": ResourceTypeType,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
+        "ResourceTags": NotRequired[Sequence["ResourceTagTypeDef"]],
     },
 )
-_OptionalListRulesRequestRequestTypeDef = TypedDict(
-    "_OptionalListRulesRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-        "ResourceTags": Sequence["ResourceTagTypeDef"],
-    },
-    total=False,
-)
-
-
-class ListRulesRequestRequestTypeDef(
-    _RequiredListRulesRequestRequestTypeDef, _OptionalListRulesRequestRequestTypeDef
-):
-    pass
-
 
 ListRulesResponseTypeDef = TypedDict(
     "ListRulesResponseTypeDef",
@@ -163,31 +139,19 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredResourceTagTypeDef = TypedDict(
-    "_RequiredResourceTagTypeDef",
+ResourceTagTypeDef = TypedDict(
+    "ResourceTagTypeDef",
     {
         "ResourceTagKey": str,
+        "ResourceTagValue": NotRequired[str],
     },
 )
-_OptionalResourceTagTypeDef = TypedDict(
-    "_OptionalResourceTagTypeDef",
-    {
-        "ResourceTagValue": str,
-    },
-    total=False,
-)
-
-
-class ResourceTagTypeDef(_RequiredResourceTagTypeDef, _OptionalResourceTagTypeDef):
-    pass
-
 
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
@@ -211,11 +175,10 @@ RetentionPeriodTypeDef = TypedDict(
 RuleSummaryTypeDef = TypedDict(
     "RuleSummaryTypeDef",
     {
-        "Identifier": str,
-        "Description": str,
-        "RetentionPeriod": "RetentionPeriodTypeDef",
+        "Identifier": NotRequired[str],
+        "Description": NotRequired[str],
+        "RetentionPeriod": NotRequired["RetentionPeriodTypeDef"],
     },
-    total=False,
 )
 
 TagResourceRequestRequestTypeDef = TypedDict(
@@ -242,29 +205,16 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateRuleRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateRuleRequestRequestTypeDef",
+UpdateRuleRequestRequestTypeDef = TypedDict(
+    "UpdateRuleRequestRequestTypeDef",
     {
         "Identifier": str,
+        "RetentionPeriod": NotRequired["RetentionPeriodTypeDef"],
+        "Description": NotRequired[str],
+        "ResourceType": NotRequired[ResourceTypeType],
+        "ResourceTags": NotRequired[Sequence["ResourceTagTypeDef"]],
     },
 )
-_OptionalUpdateRuleRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateRuleRequestRequestTypeDef",
-    {
-        "RetentionPeriod": "RetentionPeriodTypeDef",
-        "Description": str,
-        "ResourceType": ResourceTypeType,
-        "ResourceTags": Sequence["ResourceTagTypeDef"],
-    },
-    total=False,
-)
-
-
-class UpdateRuleRequestRequestTypeDef(
-    _RequiredUpdateRuleRequestRequestTypeDef, _OptionalUpdateRuleRequestRequestTypeDef
-):
-    pass
-
 
 UpdateRuleResponseTypeDef = TypedDict(
     "UpdateRuleResponseTypeDef",
